<a id="plugins.aea-cli-benchmark.aea_cli_benchmark.case_acn_communication.utils"></a>

# plugins.aea-cli-benchmark.aea`_`cli`_`benchmark.case`_`acn`_`communication.utils

Check amount of time for acn connection start.

